%% SYMBOLIC MATH
% Symbolic math examples


clear
clc

% Symbolic variables
syms x y z % Define symbolic variables

x + y + z + y + z + y % Computes this symbolic sum

% Symbolic numbers
5/3 + 3/4 % Numerical operation

sym(5)/3 + sym(3)/4 % Symbolic operation

result = sym(5)/3 + sym(3)/4;
double(result) % Transform symbolic result into numerical

% Symbolic expressions
clear

syms x a b c
q = a*x^2 + b*x + c % Quadratic function

q^2 % Compute its square
q*x % Compute q times x

q = subs(q, a, 2); % Substitute the value of the parameters
q = subs(q, b, -3);
q = subs(q, c, 5);
q

% Factorization
syms x
f = x^6 + 5*x^5 + 3*x^4 + 13*x^3 - 10*x^2 - 6*x - 30;
factor(f)

% Symbolic functios
clear

syms x y % Declara the symbolic variables
syms f(x, y)  % Declare the symbolic function
f(x,y) = x^2 + y^3 + x*y; % Define the symbolic function

f(5,3)      % Evaluate at x=5, y=3
f(x+2,y^2)  % Evaluate at x=x+2, y=y^2

% Differentiation
diff(f, x) % Partial derivate w.r.t. x
diff(f, y) % Partial derivate w.r.t. y
diff(f, y, 2) % Second Partial derivate w.r.t. x

dfx = diff(f,x);
dfx(3, 4) % Evaluate the derivate at x=3, y=4

% Integration
int(f, x)
int(f, x, 1, 5) % Definite integral

% Equation solving
clear

syms x
solve(- x^2 + 3*x - 2 == 7*x - 9) % Solve an equation

syms y
solve(x*y + x^2 + y == 5, y) % Solve for y

syms a b c
solve(a*x^2 + b*x + c) % Solve equal to 0 

pretty(solve(a*x^2 + b*x + c)) % Pretty display of the result

% Limits
syms x y
limit((3 + x)/(x-2)) % Limit x to 0
limit((3 + x)/(y-2), y, 0) % Limit y to 0

% Symbolic function/expression plotting
clear

syms x
ezplot(x^3 - x^2 + x + 5)
ezplot(x^3 - x^2 + x + 5, [-4, 4]) % Specifying the range

% Circle (x-a).^2 + (y-b).^2 = r^2
syms x y
ezplot((x - 0)^2 + (y - 0)^2 == 2^2) % Implicit function plotting

% Function plotting
syms x y
syms f(x)
f(x) = x^2 + 2*x - x;
ezplot(f)


